@@ -16,7 +16,13 @@
 def load_tests(loader, standard_tests, pattern):
     test_modules = [
         'environ',
+        'logger',
+        'monkeypatch',
+        'packagepath',
         'popen',
+        'pythonpackage',
+        'pythonpath',
+        'tempdir',
         ]
     prefix = "fixtures.tests._fixtures.test_"
     test_mod_names = [prefix + test_module for test_module in test_modules]
